@@ -1,5 +1,5 @@
 #!/bin/sh
-# @(#) $Id: jpegrotate.sh 288 2017-07-02 19:51:58Z leres $ (XSE)
+# @(#) $Id: jpegrotate.sh 302 2019-07-27 17:49:03Z leres $ (XSE)
 #
 # jpegrotate - rotate jpeg images
 #
@@ -8,25 +8,26 @@ prog="`basename $0`"
 usage()
 {
 	echo "${prog} [-n] file ...	# auto-rotate using exitags" 1>&2
-	echo "${prog} [-n] -l file ...	# rotate left" 1>&2
-	echo "${prog} [-n] -r file ...	# rotate right" 1>&2
-	echo "${prog} [-n] -f file ...	# rotate 180 (flip)" 1>&2
-	echo "${prog} [-n] -h file ...	# horizontal" 1>&2
-	echo "${prog} [-n] -V file ...	# vertical" 1>&2
-	echo "${prog} [-n] -u file ...	# undo" 1>&2
+	echo "${prog} [-nF] -l file ...	# rotate left" 1>&2
+	echo "${prog} [-nF] -r file ...	# rotate right" 1>&2
+	echo "${prog} [-nF] -f file ...	# rotate 180 (flip)" 1>&2
+	echo "${prog} [-nF] -h file ...	# horizontal" 1>&2
+	echo "${prog} [-nF] -V file ...	# vertical" 1>&2
+	echo "${prog} [-nF] -u file ...	# undo" 1>&2
 	exit 1
 }
 
 PATH=/usr/local/bin:${PATH}
 export PATH
 
+automatic=1
 dryrun=0
+force=0
 option=""
 status=0
 undo=0
-automatic=1
 
-args=`getopt fhlnruV $*`
+args=`getopt FfhlnruV $*`
 
 if [ $? -ne 0 ]; then
 	usage
@@ -49,6 +50,11 @@ for a do
 		shift
 		;;
 
+	-F)
+		force=1
+		shift
+		;;
+
 	-f)
 		option="-1"
 		automatic=0
@@ -184,12 +190,12 @@ while [ $# -gt 0 ]; do
 	esac
 
 	r="`echo ${f} | sed -e 's/r*\(\.[Jj][Pp][Gg]\)$/r\1/'`"
-	if [ "${f}" = "${r}" ]; then
+	if [ "${f}" = "${r}" -a ${force} -eq 0 ]; then
 		echo "${prog}: ${f} already rotated? (skipping)"
 		status=1
 		continue
 	fi
-	if [ -r ${r} ]; then
+	if [ -r ${r} -a ${force} -eq 0 ]; then
 		echo "${prog}: ${r} already exists, skipping ${f}"
 		status=1
 		continue
@@ -200,7 +206,7 @@ while [ $# -gt 0 ]; do
 		continue
 	fi
 	o="${f}-"
-	if [ -r ${o} ]; then
+	if [ -r ${o} -a ${force} -eq 0 ]; then
 		echo "${prog}: ${o} already exists (skipping)"
 		status=1
 		continue
@@ -265,23 +271,25 @@ while [ $# -gt 0 ]; do
 	fi
 
 	# Pick up permissions from original file
-	execute "cp -p ${f} ${r}"
+	t="${r}.$$"
+	execute "cp -p ${f} ${t}"
 	if [ $? -ne 0 ]; then
 		exit 1
 	fi
-	execute "chmod +w ${r}"
+	execute "chmod +w ${t}"
 
 	# Transform
-	execute "exiftran ${option} -o ${r} ${f}"
+	execute "exiftran ${option} -o ${t} ${f}"
 	if [ $? -ne 0 ]; then
-		rm ${r}
+		rm ${t}
 		exit 1
 	fi
 
 	# Do this last in case exiftran fails
 	execute "mv ${f} ${o}"
 
-	# Copy access and modified timestamps
+	# Rename temporary then copy access and modified timestamps
+	execute "mv ${t} ${r}"
 	execute "${touch} -r ${o} ${r}"
 	echo "${prog}: ${f} -> ${r}"
 done
