@@ -1,5 +1,5 @@
 /*
- * @(#) $Id: webindex.c 292 2018-07-21 16:09:04Z leres $ (XSE)
+ * @(#) $Id: webindex.c 300 2019-04-07 21:27:39Z leres $ (XSE)
  *
  * Copyright (c) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2013, 2015, 2016, 2017, 2018
  *	Craig Leres
@@ -118,7 +118,7 @@ const char defdatefmt[] = "%l:%M%p";
 const char deftable[] = "<table>\n";
 const char debugtable[] = "<table style=\"border: 1px;\">\n";
 const char deftr[] =
-    "<tr style=\"text-align: center; vertical-align: middle;\">\n";
+    "<tr style=\"text-align: center; vertical-align: top;\">\n";
 
 extern char *optarg;
 extern int optind, opterr, optopt;
